==> trigslink_tunnel-0.1.1-py3-none-any.whl: trigslink/ascii_logo.py <==
# trigslink/ascii_logo.py

def colorize_ascii(plain_ascii):
    result = []
    for char in plain_ascii:
        if char == "%":
            result.append("\033[38;5;18m%\033[0m") 
        elif char == "@":
            result.append(" ")  # Make @ "transparent"
        else:
            result.append(char)
    return "".join(result)

# Paste your raw ASCII here (no color codes)
_raw_ascii = r"""
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@@@@@@%%%%%%@@@@@@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@@@@%%%%%%%%%%@@@@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@@%%%%%@@@@%%%%%@@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@%%%%%@@@@@@@@%%%%@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@%%%%%@@@@@@@@@@@@%%%%@@@@@@@@@@@@@@@
@@@@@@@@@@@@@%%%%@@@@@@@@@@@@@@@@%%%%@@@@@@@@@@@@@
@@@@@@@@@@@%%%%@@@@@@@@@@@@@@@@@@@@%%%%@@@@@@@@@@@
@@@@@@@@@%%%%%@@@@@+::+@@@@+::*@@@@@%%%%%@@@@@@@@@
@@@@@@@%%%%%%%%@@@@#++#@@@@#++#@@@@%%%%%%%%@@@@@@@
@@@@@%%%%%@@@@%%@@@@@@@@@@@@@@@@@%%%@@@@%%%%%@@@@@
@@@@%%%%@@@@@@@@%%@@%@@@@@@@@%@@%%@@@@@@@@%%%%%@@@
@@%%%%@@@@@@@@@@@@%@@@@@@@@@@@@@@@@@@@@@@@@@%%%%@@
@@%%%%@@@@@%%@@@@@@@@@@@@@@@@@@@@@@@@%%@@@@@%%%%@@
@@%%%%@@@@@@%%%@@@@@@@@@@@@@@@@@@@@%%%@@@@@@%%%%@@
@@@%%%%%@@@%%%@@@@@@@@@@@@@@@@@@@@@@%%@@@@%%%%@@@@
@@@@@%%%%%%%@@@@@@%%%%%@@@@%%%%%@@@@@@%%%%%%@@@@@@
@@@@@@@%%%%%@@@@@@@@@@@%%%%@@@@@@@@@@@%%%%@@@@@@@@
@@@@@@@@@%%%%%@@@@@@@@@@@%%@@@@@@@@@%%%%%@@@@@@@@@
@@@@@@@@@@@%%%%%@@@@@@@@@@%%@@@@@@%%%%%@@@@@@@@@@@
@@@@@@@@@@@@@%%%%%@%%%@@@@@@%%%@%%%%%@@@@@@@@@@@@@
@@@@@@@@@@@@@@@%%%%%%%%%@@@@@%%%%%%@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@%%%%%%@@@@@@%%%%@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@@@%%%%@@@@%%%%%@@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@@@@@%%%%%%%%%@@@@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@@@@@@@%%%%%@@@@@@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
"""

TRIGSLINK_ASCII = colorize_ascii(_raw_ascii)

==> trigslink_tunnel-0.1.2-py3-none-any.whl: trigslink/ascii_logo.py <==
# trigslink/ascii_logo.py

def colorize_ascii(plain_ascii):
    result = []
    for char in plain_ascii:
        if char == "%":
            result.append("\033[38;5;18m%\033[0m") 
        elif char == "@":
            result.append(" ")  # Make @ "transparent"
        else:
            result.append(char)
    return "".join(result)

# Paste your raw ASCII here (no color codes)
_raw_ascii = r"""
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@@@@@@%%%%%%@@@@@@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@@@@%%%%%%%%%%@@@@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@@%%%%%@@@@%%%%%@@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@%%%%%@@@@@@@@%%%%@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@%%%%%@@@@@@@@@@@@%%%%@@@@@@@@@@@@@@@
@@@@@@@@@@@@@%%%%@@@@@@@@@@@@@@@@%%%%@@@@@@@@@@@@@
@@@@@@@@@@@%%%%@@@@@@@@@@@@@@@@@@@@%%%%@@@@@@@@@@@
@@@@@@@@@%%%%%@@@@@::::@@@@::::@@@@@%%%%%@@@@@@@@@
@@@@@@@%%%%%%%%@@@@::::@@@@::::@@@@%%%%%%%%@@@@@@@
@@@@@%%%%%@@@@%%@@@@@@@@@@@@@@@@@%%%@@@@%%%%%@@@@@
@@@@%%%%@@@@@@@@%%@@%@@@@@@@@%@@%%@@@@@@@@%%%%%@@@
@@%%%%@@@@@@@@@@@@%@@@@@@@@@@@@@@@@@@@@@@@@@%%%%@@
@@%%%%@@@@@%%@@@@@@@@@@@@@@@@@@@@@@@@%%@@@@@%%%%@@
@@%%%%@@@@@@%%%@@@@@@@@@@@@@@@@@@@@%%%@@@@@@%%%%@@
@@@%%%%%@@@%%%@@@@@@@@@@@@@@@@@@@@@@%%@@@@%%%%@@@@
@@@@@%%%%%%%@@@@@@%%%%%@@@@%%%%%@@@@@@%%%%%%@@@@@@
@@@@@@@%%%%%@@@@@@@@@@@%%%%@@@@@@@@@@@%%%%@@@@@@@@
@@@@@@@@@%%%%%@@@@@@@@@@@%%@@@@@@@@@%%%%%@@@@@@@@@
@@@@@@@@@@@%%%%%@@@@@@@@@@%%@@@@@@%%%%%@@@@@@@@@@@
@@@@@@@@@@@@@%%%%%@%%%@@@@@@%%%@%%%%%@@@@@@@@@@@@@
@@@@@@@@@@@@@@@%%%%%%%%%@@@@@%%%%%%@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@%%%%%%@@@@@@%%%%@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@@@%%%%@@@@%%%%%@@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@@@@@%%%%%%%%%@@@@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@@@@@@@%%%%%@@@@@@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
"""

TRIGSLINK_ASCII = colorize_ascii(_raw_ascii)
